package com.ruoyi.pt.quartz;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.ruoyi.pt.service.RemoteCallsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

/**
 * 推送平台数据定时任务
 *
 * @author wu
 * @since 2023/12/26 16:19
 */
@Component
@EnableScheduling
@Async
public class PushQuartz {

    public static final Logger log = LoggerFactory.getLogger(PushQuartz.class);
    @Resource
    private RemoteCallsService remoteCallsService;

    @Scheduled(cron = "0 0 */1 * * ?")
    public synchronized void pushData() {
        DateTime dataTime = DateUtil.date();
        // 获取上个小时
        String lastHourStr = DateUtil.offsetHour(dataTime, -1).toString("yyyy-MM-dd HH:mm:ss");
        // 获取当前时间
        String localDateStr = DateUtil.beginOfDay(dataTime).toString("yyyy-MM-dd HH:mm:ss");
        log.info("==============开始定时任务" + localDateStr + "============");
        // 过滤审核不通过的事件列表
        log.info("==============过滤审核不通过的事件列表" + "============");
        remoteCallsService.noPassEventList(lastHourStr, localDateStr);
        // 过滤已办结的事件列表
        log.info("==============过滤已办结的事件列表" + "============");
        remoteCallsService.completionEventList(lastHourStr, localDateStr);
        // 拉取社会治理中心增量事件保存到events_import表
        remoteCallsService.getEventDate();
        // 获取今天的时间
        LocalDate localDate = LocalDate.now();
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
        String localTimeStr = localDate.format(formatter);
        // 紧急事件接口
        log.info("==============推送紧急事件接口" + LocalDateTime.now() + "============");
        remoteCallsService.urgentAlgorithm(localTimeStr);
        // 重点人员接口
        log.info("==============推送重点人员接口" + LocalDateTime.now() + "============");
        remoteCallsService.keypersonAlgorithm(localTimeStr);
        // 群体事件接口
        log.info("==============推送群体事件接口" + LocalDateTime.now() + "============");
        remoteCallsService.groupAlgorithm();
        // 同人事件接口
        log.info("==============推送同人事件接口" + LocalDateTime.now() + "============");
        remoteCallsService.onepersonAlgorithm();
        // 推送
        log.info("==============推送到预警平台接口" + LocalDateTime.now() + "============");
        remoteCallsService.imports(1);
    }
}
